exceptions
==================================================
**Module**: :mod:`espressodb.base.exceptions`

.. currentmodule:: espressodb.base.exceptions

.. autosummary::
   ConsistencyError

------

.. automodule:: espressodb.base.exceptions
    :members:
    :special-members:
